package com.mdd.admin.validate.setting;

import com.mdd.common.validator.annotation.IDMust;
import com.mdd.common.validator.annotation.IntegerContains;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;
import org.hibernate.validator.constraints.Length;

@ApiModel("字典数据更新参数")
public class DictDataUpdateValidate implements Serializable {
   private static final long serialVersionUID = 1L;
   @IDMust(
      message = "id参数必传且需大于0"
   )
   @ApiModelProperty(
      value = "ID",
      required = true
   )
   private Integer id;
   @IDMust(
      message = "typeId参数必传且需大于0"
   )
   @ApiModelProperty(
      value = "类型ID",
      required = true
   )
   private Integer typeId;
   @ApiModelProperty(
      value = "键",
      required = true
   )
   private @NotNull(
   message = "name参数缺失"
) String name;
   @ApiModelProperty(
      value = "值",
      required = true
   )
   private @NotNull(
   message = "value参数缺失"
) @Length(
   max = 100,
   message = "键名不能超出100个字符"
) String value;
   @ApiModelProperty("备注")
   private @Length(
   max = 200,
   message = "数值不能超出200个字符"
) String remark;
   @ApiModelProperty("排序")
   private @DecimalMin(
   value = "0",
   message = "排序号值不能少于0"
) Integer sort;
   @IntegerContains(
      values = {0, 1},
      message = "status参数不在合法值内"
   )
   @ApiModelProperty(
      value = "状态",
      required = true
   )
   private @NotNull(
   message = "status参数缺失"
) Integer status;

   public Integer getId() {
      return this.id;
   }

   public Integer getTypeId() {
      return this.typeId;
   }

   public @NotNull(
   message = "name参数缺失"
) String getName() {
      return this.name;
   }

   public @NotNull(
   message = "value参数缺失"
) String getValue() {
      return this.value;
   }

   public String getRemark() {
      return this.remark;
   }

   public Integer getSort() {
      return this.sort;
   }

   public @NotNull(
   message = "status参数缺失"
) Integer getStatus() {
      return this.status;
   }

   public void setId(Integer id) {
      this.id = id;
   }

   public void setTypeId(Integer typeId) {
      this.typeId = typeId;
   }

   public void setName(@NotNull(
   message = "name参数缺失"
) String name) {
      this.name = name;
   }

   public void setValue(@NotNull(
   message = "value参数缺失"
) String value) {
      this.value = value;
   }

   public void setRemark(String remark) {
      this.remark = remark;
   }

   public void setSort(Integer sort) {
      this.sort = sort;
   }

   public void setStatus(@NotNull(
   message = "status参数缺失"
) Integer status) {
      this.status = status;
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof DictDataUpdateValidate)) {
         return false;
      } else {
         DictDataUpdateValidate other = (DictDataUpdateValidate)o;
         if (!other.canEqual(this)) {
            return false;
         } else {
            label95: {
               Object this$id = this.getId();
               Object other$id = other.getId();
               if (this$id == null) {
                  if (other$id == null) {
                     break label95;
                  }
               } else if (this$id.equals(other$id)) {
                  break label95;
               }

               return false;
            }

            Object this$typeId = this.getTypeId();
            Object other$typeId = other.getTypeId();
            if (this$typeId == null) {
               if (other$typeId != null) {
                  return false;
               }
            } else if (!this$typeId.equals(other$typeId)) {
               return false;
            }

            Object this$sort = this.getSort();
            Object other$sort = other.getSort();
            if (this$sort == null) {
               if (other$sort != null) {
                  return false;
               }
            } else if (!this$sort.equals(other$sort)) {
               return false;
            }

            label74: {
               Object this$status = this.getStatus();
               Object other$status = other.getStatus();
               if (this$status == null) {
                  if (other$status == null) {
                     break label74;
                  }
               } else if (this$status.equals(other$status)) {
                  break label74;
               }

               return false;
            }

            label67: {
               Object this$name = this.getName();
               Object other$name = other.getName();
               if (this$name == null) {
                  if (other$name == null) {
                     break label67;
                  }
               } else if (this$name.equals(other$name)) {
                  break label67;
               }

               return false;
            }

            Object this$value = this.getValue();
            Object other$value = other.getValue();
            if (this$value == null) {
               if (other$value != null) {
                  return false;
               }
            } else if (!this$value.equals(other$value)) {
               return false;
            }

            Object this$remark = this.getRemark();
            Object other$remark = other.getRemark();
            if (this$remark == null) {
               if (other$remark != null) {
                  return false;
               }
            } else if (!this$remark.equals(other$remark)) {
               return false;
            }

            return true;
         }
      }
   }

   protected boolean canEqual(Object other) {
      return other instanceof DictDataUpdateValidate;
   }

   public int hashCode() {
      int PRIME = true;
      int result = 1;
      Object $id = this.getId();
      result = result * 59 + ($id == null ? 43 : $id.hashCode());
      Object $typeId = this.getTypeId();
      result = result * 59 + ($typeId == null ? 43 : $typeId.hashCode());
      Object $sort = this.getSort();
      result = result * 59 + ($sort == null ? 43 : $sort.hashCode());
      Object $status = this.getStatus();
      result = result * 59 + ($status == null ? 43 : $status.hashCode());
      Object $name = this.getName();
      result = result * 59 + ($name == null ? 43 : $name.hashCode());
      Object $value = this.getValue();
      result = result * 59 + ($value == null ? 43 : $value.hashCode());
      Object $remark = this.getRemark();
      result = result * 59 + ($remark == null ? 43 : $remark.hashCode());
      return result;
   }

   public String toString() {
      return "DictDataUpdateValidate(id=" + this.getId() + ", typeId=" + this.getTypeId() + ", name=" + this.getName() + ", value=" + this.getValue() + ", remark=" + this.getRemark() + ", sort=" + this.getSort() + ", status=" + this.getStatus() + ")";
   }
}
